@@ -449,8 +449,10 @@ def test_update_cache(mocker, monkeypatch, capsys):
         == """Updating local cache:
 * Rootfs:
   * qemu-arm64
+  * qemu-arm64be
   * qemu-armv5
   * qemu-armv7
+  * qemu-armv7be
   * qemu-i386
   * qemu-mips32
   * qemu-mips32el
