@@ -11,6 +11,7 @@ from tuxrun.tests import Test
 class LTPTest(Test):
     device = "qemu-*"
     cmdfile: str = ""
+    need_test_definition = True
 
     def render(self, **kwargs):
         kwargs["name"] = self.name
@@ -34,7 +35,7 @@ class LTPFcntlLockTests(LTPTest):
 
 class LTPFSBind(LTPTest):
     name = "ltp-fs_bind"
-    timeout = 15
+    timeout = 25
 
 
 class LTPFSPermsSimple(LTPTest):
